@@ -34,18 +34,11 @@
 # @author
 #*/###########################################################################
 setConstructorS3("UnitTypesFile", function(...) {
-  extend(UnitAnnotationDataFile(...), "UnitTypesFile");
+  extend(UnitAnnotationDataFile(...), "UnitTypesFile")
 })
 
-setMethodS3("getUnitTypes", "UnitTypesFile", abstract=TRUE);
+setMethodS3("getUnitTypes", "UnitTypesFile", abstract=TRUE)
 
 setMethodS3("nbrOfUnits", "UnitTypesFile", function(this, ...) {
-  length(getUnitTypes(this));
+  length(getUnitTypes(this))
 })
-
-
-############################################################################
-# HISTORY:
-# 2009-07-08
-# o Created from UnitTypesFile.R.
-############################################################################
